import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import 'rxjs/add/operator/toPromise';
import { Context } from './context';
import { SearchResult } from '../../search/models/search-result';
import { SearchRequest } from '../../search/models/search-request';
import { CatalogOptions } from '../../custom/models/catalog-options';
import { Clasificacion } from '../../general/models/clasificacion';
import { BaseService } from './base-service';
import { CatalogInfo, CatalogItem } from '../models/catalog';
/**
*Interface de servicios básicos para un catálogo
*/
export interface ICatalogService<TInfo extends CatalogInfo> {
    create(): Promise<TInfo>;
    getOptions(): Promise<CatalogOptions>;
    update(info: TInfo): Promise<TInfo>;
    getDetailByID(itemID: number): Promise<TInfo>;
    getDetailByCode(idBranch: number, code: string): Promise<TInfo>;
    getDetailFromCache(itemID: number): Promise<TInfo>;
    clone(itemID: number): Promise<TInfo>;
    delete(itemID: number): Promise<any>;
    exists(itemID: number): Promise<boolean>;
    export(itemID: number): Promise<any>;
    changeStatus(itemID: Number, active: boolean): Promise<any>;
    sync(lastUpdate: Date): Promise<any>;
    search(idBranch: number, request: SearchRequest): Promise<SearchResult>;
    searchKeyword(idBranch: number, keryword: string): Observable<CatalogItem[]>;
    loadClassifiers(idBranch: number): Promise<Clasificacion[]>;
}
/**
 * Clase base para servicios básicos de un catálogo
 */
export declare abstract class CatalogService<TInfo extends CatalogInfo> extends BaseService implements ICatalogService<TInfo> {
    protected http: HttpClient;
    protected context: Context;
    protected serviceUrl: string;
    options: CatalogOptions;
    classifiers: Clasificacion[];
    constructor(http: HttpClient, context: Context, serviceUrl: string);
    abstract create(): Promise<TInfo>;
    /**
     * Carga las opciones de configuración del catálogo
     */
    getOptions(): Promise<CatalogOptions>;
    /**
     * Envía la información al servidor
     * @param info Paquete de información que se enviará al servidor
     */
    update(info: TInfo): Promise<TInfo>;
    /**
     * Carga la información del ID especificado
     * @param itemID ID del elemento a cargar
     */
    getDetailByID(itemID: number): Promise<TInfo>;
    /**
     * Carga la información del elemento especificado a través de su código de usuario
     * @param idBranch En caso del que el código no sea único, se buscará en la sucursal especificada
     * @param code Codigo del elemento
     */
    getDetailByCode(idBranch: number, code: string): Promise<TInfo>;
    /**
     * Carga la información del elemento con ID, pero primero lo buscará en la caché del servidor
     * @param itemID ID del elemento a cargar
     */
    getDetailFromCache(itemID: number): Promise<TInfo>;
    /**
     * Crea una copia del elemento con el ID especificado
     * @param itemID ID del elemento a clonar
     */
    clone(itemID: number): Promise<TInfo>;
    /**
     * Crea una copia del objecto especificado
     * @param info Objeto a clonar
     */
    copy(info: TInfo): TInfo;
    /**
     * Elimina el elemento con el ID especificado
     * @param itemID ID del elemento a eliminar
     */
    delete(itemID: number): Promise<any>;
    /**
     * Verifica si existe un elemento con el ID especificado
     * @param itemID ID del elemento a verificar
     */
    exists(itemID: number): Promise<boolean>;
    /**
     * Ejecuta el proceso de exportación a otros sistemas o formatos
     * @param itemID
     */
    export(itemID: number): Promise<any>;
    /**
     * Cambia el estado del elemento con el ID especificado
     * @param itemID ID del elemento a cambiar
     * @param active Nuevo estatus
     */
    changeStatus(itemID: number, active: boolean): Promise<any>;
    /**
     * Obtiene los registros que cambiaron desde la fecha especificada
     * @param lastUpdate Fecha desde la cual se obtendrán los registros modificados
     */
    sync(lastUpdate: Date): Promise<any>;
    /**
     * Realiza una búsqueda de los registros que cumplen con ciertas condiciones
     * @param idBranch ID de la sucursal donde se realizará la busqueda, algunos catálogos ignoran éste parámetro
     * @param request Condiciones de la búsqueda, orden de los resultados y parámetros de paginación
     */
    search(idBranch: number, request: SearchRequest): Promise<SearchResult>;
    /**
     * Realiza la búsqueda de los elementos que coinciden con una palabra clave
     * @param idBranch Sucursal dóndde se acotará la búsqueda. Algunos catálogos ingnoran éste parámetro
     * @param keryword Palabra clave que se buscará
     */
    searchKeyword(idBranch: number, keyword: string): Observable<CatalogItem[]>;
    /**
     * Carga los clasificadores de los grupos de clasificación asignados a la entidad
     * @param idBranch Se filtrarán sólo los clasificadores registrados en la empresa a la que pertenece la sucursal especificada
     */
    loadClassifiers(idBranch: number): Promise<Clasificacion[]>;
    applyAction(itemID: number, action: string, data: any): Promise<boolean>;
    protected handleError(error: any): Promise<any>;
}
